@@ -6,17 +6,24 @@ use core::time::Duration;
 
 pub struct Etime {
     start: AtomicU64,
+    clock: fn() -> u64,
 }
 impl Etime {
+    const CLOCK_SOURCE: fn() -> u64 = clock_source::now;
     pub const fn new() -> Self {
         Self {
             start: AtomicU64::new(0),
+            clock: Self::CLOCK_SOURCE,
         }
     }
     // ns
+    pub fn set_clock(&mut self, clock: fn() -> u64) {
+        self.clock = clock;
+    }
+    // ns
     #[inline]
     pub fn now(&self) -> u64 {
-        clock_source::now()
+        (self.clock)()
     }
     pub fn tic(&self) {
         let now = self.now();
